<?php

namespace Drupal\classes_extractor;

use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Manager Service for Classes Extractor Module.
 */
class ClassesExtractorManager {

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Used of entity type manager.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   */

  /**
   * Construct.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
  ) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Recursively get classes from settings.
   */
  public function recursiveGetClasses(array $settings, array &$classes) {
    foreach ($settings as $key => $value) {
      if (is_array($value)) {
        $this->recursiveGetClasses($value, $classes);
      }
      else {
        if (
        strpos($key, 'class') !== FALSE
        || strpos($key, 'classes') !== FALSE
        ) {
          if ($value && is_string($value)) {
            if (strpos($value, PHP_EOL) !== FALSE) {
              $value = explode(PHP_EOL, $value);
              foreach ($value as &$v) {
                if (strpos($v, '|') !== FALSE) {
                  $v = explode('|', $v)[0];
                }
                else {
                  $v = trim($v);
                }
              }
              $value = implode(' ', $value);
            }

            $classes[] = $value;
          }
        }
        if (strpos($key, 'attributes') !== FALSE && is_string($value)) {
          // Attributes like "class|test best,data-id|2".
          $attributes = explode(',', $value);
          foreach ($attributes as $attribute) {
            $attribute = explode('|', $attribute);
            if (count($attribute) === 2 && $attribute[0] === 'class') {
              $classes = array_merge($classes, explode(' ', $attribute[1]));
            }
          }
        }
      }
    }
  }

  /**
   * Get all classes from plugins.
   */
  public function getAllClasses() {
    $plugin_manager = \Drupal::service('plugin.manager.classes_extractor');
    $plugins = $plugin_manager->getDefinitions();
    $classes = [];
    // Collect all classes from plugins.
    foreach ($plugins as $plugin_id => $plugin_definition) {
      $plugin = $plugin_manager->createInstance($plugin_id);
      $plugin_classes = $plugin->getClasses();
      if (is_array($plugin_classes)) {
        foreach ($plugin_classes as $class) {
          // Split any class by spaces or `|` characters.
          $classes = array_merge($classes, preg_split('/[\s|]+/', $class));
        }
      }
    }
    // Remove duplicates and filter out empty values.
    $unique_classes = array_values(array_unique(array_filter($classes, 'strlen')));
    // Return as a space-separated string.
    return implode(' ', $unique_classes);
  }

}
