<?php

namespace Drupal\classes_extractor\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration Form Of Class Extractor Module.
 */
class ClassesExtractorConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'classes_extractor.configform',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'classes_extractor_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('classes_extractor.configform');

    $form['file_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Classes Extractor File Path'),
      '#description' => $this->t('Provide the file path to add the classes, ensuring that the file exists and has write permissions'),
      '#field_prefix' => DRUPAL_ROOT . '/',
      '#max_length' => 255,
      '#default_value' => $config->get('file_path'),
      '#required' => TRUE,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('classes_extractor.configform')
      ->set('file_path', $form_state->getValue('file_path'))
      ->save();
  }

  /**
   * Title of Form.
   */
  public function getTitle() {
    return t('Classes Extractor Config Form');
  }

}
